GenJAXMix is a GenJAX-accelerated Dirichlet Process Mixture Modeling package for heterogenous tabular data.

# Installation

Currently GenJAXMix is not registered on a package index. Please install via pip:


```bash
pip install git+https://github.com/OpenGen/genjaxmix.git
```

# Development

```bash
uv sync
```

## Disclaimer

This is a research project. Expect bugs and sharp edges. Please help by trying out `genjaxmix`, [reporting bugs](https://github.com/ChiSym/genjaxmix/issues), and letting us know what you think!

## Get Involved + Get Support

Pull requests and bug reports are always welcome!

The TL;DR; is:

- send us a pull request,
- iterate on the feedback + discussion, and
- get a +1 from a maintainer

in order to get your PR accepted.

Issues should be reported on the [GitHub issue tracker](https://github.com/ChiSym/genjaxmix/issues).

If you want to discuss an idea for a new feature or ask us a question, discussion occurs primarily in the body of [Github Issues](https://github.com/ChiSym/genjaxmix/issues)

<div align="center">
All code is licensed under the <a href="LICENSE">Apache 2.0 License</a>.
</div>
